[![builds.sr.ht status](https://builds.sr.ht/~qeef/py-ava.svg)](https://builds.sr.ht/~qeef/py-ava?)
[![Documentation Status](https://readthedocs.org/projects/py-ava/badge/?version=latest)](https://py-ava.readthedocs.io/en/latest/?badge=latest)

https://git.sr.ht/~qeef/py-ava repository contains Automated Vehicle
Architecture packages written in Python3 with object-oriented paradigm.

`pdc` package contains two modules:

- `dp` module with classes for perception.
- `bqs` module with classes for decision and control.

To contribute, please::

    git config format.subjectPrefix "PATCH py-ava"
    git config sendemail.to "~qeef/public-inbox@lists.sr.ht"
